SqlFunServerApi

Trait SqlFunServerApi 

pub trait SqlFunServerApi {
    // Required methods
    fn initialize_schema_context<'life0, 'async_trait>(
        &'life0 self,
        args: InitializeSchemaArgs,
    ) -> Pin<Box<dyn Future<Output = Result<SchemaContext, SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn read_collection<'life0, 'async_trait>(
        &'life0 self,
        args: ReadCollectionArgs,
    ) -> Pin<Box<dyn Future<Output = Result<Value, SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn release_collection<'life0, 'async_trait>(
        &'life0 self,
        args: ReleaseCollectionArgs,
    ) -> Pin<Box<dyn Future<Output = Result<(), SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn analyze_query<'life0, 'async_trait>(
        &'life0 self,
        args: AnalyzeQueryArgs,
    ) -> Pin<Box<dyn Future<Output = Result<AnalyzeQueryResponse, SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn list_objects<'life0, 'async_trait>(
        &'life0 self,
        args: ListObjectArgs,
    ) -> Pin<Box<dyn Future<Output = Result<Collection<ObjectSummary>, SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn describe_table<'life0, 'async_trait>(
        &'life0 self,
        args: DescribeTableArgs,
    ) -> Pin<Box<dyn Future<Output = Result<DescribeTableResponse, SqlFunServerApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
sql-fun Server API functions

Required Methods

fn initialize_schema_context<'life0, 'async_trait>( &'life0 self, args: InitializeSchemaArgs, ) -> Pin<Box<dyn Future<Output = Result<SchemaContext, SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Initialize schema-aware query analysis context

fn read_collection<'life0, 'async_trait>( &'life0 self, args: ReadCollectionArgs, ) -> Pin<Box<dyn Future<Output = Result<Value, SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Read a collection

When server returns multiple items, server keeps scrollable collection, [read_collection] reads items in collection.

Return value

returns Collection, T depends collection item type

fn release_collection<'life0, 'async_trait>( &'life0 self, args: ReleaseCollectionArgs, ) -> Pin<Box<dyn Future<Output = Result<(), SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Release a collection

When server returns collection, server keeps scrollable collection, [release_collection] release a server side collection.

fn analyze_query<'life0, 'async_trait>( &'life0 self, args: AnalyzeQueryArgs, ) -> Pin<Box<dyn Future<Output = Result<AnalyzeQueryResponse, SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

analyze query

fn list_objects<'life0, 'async_trait>( &'life0 self, args: ListObjectArgs, ) -> Pin<Box<dyn Future<Output = Result<Collection<ObjectSummary>, SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

list schema objects

fn describe_table<'life0, 'async_trait>( &'life0 self, args: DescribeTableArgs, ) -> Pin<Box<dyn Future<Output = Result<DescribeTableResponse, SqlFunServerApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

describe a table

Implementors